@@ -30,7 +30,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 %EXPORT_TAGS = (DEFAULT => [qw(&user_sign_is_valid &calc_pub_key_id &encrypt &send_doc &get_docs &split_base64)]);
 
 BEGIN {
-  $VERSION = '0.4';
+  $VERSION = '0.5';
 }
 
 =head1 NAME
@@ -110,7 +110,11 @@ document - hash with structured document description like:
 
 client_password - client password
 
-=head2 get_docs(client_password, get_one_doc function, unixtime from_time)
+Return true, if success delivering
+
+=head2 get_docs(site, client_password, get_one_doc function, unixtime from_time)
+
+site - client site identification name
 
 client_password - client password
 
@@ -251,16 +255,18 @@ sub send_doc {
   if (!$resp->is_success) {
     warn "HTTP request error ".$resp->code." - ".$resp->message;
   }
+
+  return($resp->is_success);
 };
 
 sub get_docs {
-  my ($client_password, $get_doc_func, $from_time) = @_;
+  my ($site, $client_password, $get_doc_func, $from_time) = @_;
 
   $from_time = time() - 3600*24 if !defined($from_time);
   
   my $doc_request = {
     type => 'CLIENT_REQUEST',
-    site => 'test',
+    site => $site,
     from_time => $from_time,
   };
   
